@@ -10,7 +10,8 @@ our @ISA = qw(Exporter);
 our @EXPORT_OK = 
   qw(PRIVATE_PREFIX META_ATTR_NAME ON_SAVE_ATTR_NAME 
      LOADED_FROM_DRIVER FLAG_DB_IS_PRIVATE MODIFIED_COLUMNS SET_COLUMNS 
-     STATE_IN_DB STATE_LOADING STATE_SAVING STATE_CLONING);
+     STATE_IN_DB STATE_LOADING STATE_SAVING STATE_CLONING
+     EXCEPTION_CODE_NO_KEY);
 
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
@@ -26,4 +27,6 @@ use constant STATE_LOADING      => PRIVATE_PREFIX . '_loading';
 use constant STATE_SAVING       => PRIVATE_PREFIX . '_saving';
 use constant STATE_CLONING      => STATE_SAVING;
 
+use constant EXCEPTION_CODE_NO_KEY => 5; # arbitrary
+
 1;
